---
name: Usage question
about: How do I use the library and API?
title: ''
labels: ''
assignees:

---

# Note
This issue tracker is for **bug reports**. Please don't ask about how to use the library here – the docs are comprehensive and include examples: https://pyzotero.readthedocs.io.

You can also ask questions on the forum: https://forums.zotero.org/discussions

A guide to the Zotero API itself is here: https://www.zotero.org/support/dev/web_api/v3/start
